var phidget22 = require('phidget22');

var SERVER_PORT = 5661;

function main() {

	if (process.argv.length != 3) {
		console.log('usage: node VoltageOutput.js <server address>');
		process.exit(1);
	}
	var hostname = process.argv[2];

	console.log('connecting to:' + hostname);
	var conn = new phidget22.Connection(SERVER_PORT, hostname, { name: 'Server Connection', passwd: '' });
	conn.connect()
		.then(runExample)
		.catch(function (err) {
			console.error('Error running example:', err.message);
			process.exit(1);
		});
}

function runExample() {

	console.log('connected to server');
	var ch = new phidget22.VoltageOutput();

	var exTimer;

	function updateVoltage() {
		var newVoltage = ch.getVoltage() + 2;
		if (newVoltage > 4)
			newVoltage = 0;
		console.log('\nSetting voltage to ' + newVoltage + 'V for 5 seconds...');
		ch.setVoltage(newVoltage);
	}

	ch.onAttach = function (ch) {
		console.log(ch + ' attached');
		console.log('\nSetting voltage to 0V for 5 seconds...');
		if (ch.getDeviceID() == phidget22.DeviceID.PN_1002) {
			ch.setVoltage(0);
			ch.setEnabled(1);
		}
		exTimer = setInterval(function () { updateVoltage() }, 5000);
	};

	ch.onDetach = function (ch) {
		console.log(ch + ' detached');
		clearInterval(exTimer);
	};

	ch.open().then(function (ch) {
		console.log('channel open');
	}).catch(function (err) {
		console.log('failed to open the channel:' + err);
	});
}

if (require.main === module)
	main();
